pub struct BatchProcessor;Expand description
Helper for processing batch requests
Implementations
Sourceimpl BatchProcessor
impl BatchProcessor
Sourcepub async fn process<F, Fut>(
batch: BatchRequest,
handler: F,
) -> McpResult<BatchResponse>
pub async fn process<F, Fut>( batch: BatchRequest, handler: F, ) -> McpResult<BatchResponse>
Process a batch request and return a batch response
Sourcepub fn parse_error() -> BatchResponse
pub fn parse_error() -> BatchResponse
Create a parse error response for invalid batch JSON
Sourcepub fn empty_batch_error() -> BatchResponse
pub fn empty_batch_error() -> BatchResponse
Create an empty batch error response